/******************************************************************************
* C Source: Field List                                                        *
*                                                                             *
* File:                                                                       *
*    fieldlst.c                                                               *
*                                                                             *
* Description:                                                                *
*    This set of functions performs various manipulations on a linked list    *
*    (see lnkd_lst.c and lnkd_lst.h) of Fields (see field.c and field.h),     *
*    each node for an individual field. (see fieldlst.h).                     *
*                                                                             *
* Module List:                                                                *
*    Add_Field_to_List                                                        *
*       Insert a field into the top of a field list.                          *
*    Create_Empty_Field_List                                                  *
*       Create a new empty field list.                                        *
*    Delete_Field_List                                                        *
*       Delete the linked list for a field list, but not the field data the   *
*       list points to.                                                       *
*    Delete_Field_List_Data                                                   *
*       Delete the linked list for a field list, AND the field data the list  *
*       points to.                                                            *
*                                                                             *
* History:                                                                    *
*    Created    : 17-AUG-93 by J. Doggett,                                    *
*       for the Association of Universities for Research in Astronomy, Inc.   *
*          at the Space Telescope Science Institute,                          *
*       to facilitate the accessing of data from the CD-ROM set of the        *
*          Digitized Sky Survey.                                              *
*    Delivered  : 01-MAR-94 by J. Doggett,                                    *
*       GetImage Version 1.0                                                  *
*                                                                             *
* Copyright (c) 1993, 1994, Association of Universities for Research in       *
* Astronomy, Inc.  All Rights Reserved.                                       *
* Produced under National Aeronautics and Space Administration grant          *
* NAG W-2166.                                                                 *
******************************************************************************/
#include "fieldlst.h"

#include "field.h"
#include "lnkd_lst.h"

/******************************************************************************
* Module:                                                                     *
*    Add_Field_to_List                                                        *
*                                                                             *
* File:                                                                       *
*    fieldlst.c                                                               *
*                                                                             *
* Description:                                                                *
*    Adds a field to the top of a field list.                                 *
*                                                                             *
* Return Value:                                                               *
*    none                                                                     *
*                                                                             *
* Arguments;                                                                  *
*                                                                             *
*    Input Arguments:                                                         *
*       List                                                                  *
*          FIELD_LIST, Reference                                              *
*             The field list to which we're adding the field.                 *
*       Field                                                                 *
*          FIELD, Reference                                                   *
*             The field we're adding to the field list.                       *
*    Input/Output Arguments:                                                  *
*       none                                                                  *
*    Output Arguments:                                                        *
*       none                                                                  *
*                                                                             *
* History:                                                                    *
*    Created    : 17-AUG-93 by J. Doggett,                                    *
*       for the Association of Universities for Research in Astronomy, Inc.   *
*          at the Space Telescope Science Institute,                          *
*       to facilitate the accessing of data from the CD-ROM set of the        *
*          Digitized Sky Survey.                                              *
*    Delivered  : 01-MAR-94 by J. Doggett,                                    *
*       GetImage Version 1.0                                                  *
******************************************************************************/
/*********************************
* Add_Field_to_List declarations *
*********************************/
void       Add_Field_to_List( List, Field )
FIELD_LIST List ;
FIELD      Field;
{
/******************************************
* Add_Field_to_List begin executable code *
******************************************/
   Insert_Linked_List_Data( List, Field );

   return;
}
/****************************************
* Add_Field_to_List end executable code *
****************************************/

/******************************************************************************
* Module:                                                                     *
*    Create_Empty_Field_List                                                  *
*                                                                             *
* File:                                                                       *
*    fieldlst.c                                                               *
*                                                                             *
* Description:                                                                *
*    Create a new empty field list, allocating memory for the header.         *
*    the memory.                                                              *
*                                                                             *
* Return Value:                                                               *
*    FIELD_LIST: The newly created field.                                     *
*                                                                             *
* Arguments;                                                                  *
*                                                                             *
*    Input Arguments:                                                         *
*       none                                                                  *
*    Input/Output Arguments:                                                  *
*       none                                                                  *
*    Output Arguments:                                                        *
*       none                                                                  *
*                                                                             *
* History:                                                                    *
*    Created    : 17-AUG-93 by J. Doggett,                                    *
*       for the Association of Universities for Research in Astronomy, Inc.   *
*          at the Space Telescope Science Institute,                          *
*       to facilitate the accessing of data from the CD-ROM set of the        *
*          Digitized Sky Survey.                                              *
*    Delivered  : 01-MAR-94 by J. Doggett,                                    *
*       GetImage Version 1.0                                                  *
******************************************************************************/
/***************************************
* Create_Empty_Field_List declarations *
***************************************/
FIELD_LIST Create_Empty_Field_List()
{
/************************************************
* Create_Empty_Field_List begin executable code *
************************************************/
   return ( FIELD_LIST )Create_Empty_Linked_List();
}
/**********************************************
* Create_Empty_Field_List end executable code *
**********************************************/

/******************************************************************************
* Module:                                                                     *
*    Delete_Field_List                                                        *
*                                                                             *
* File:                                                                       *
*    fieldlst.c                                                               *
*                                                                             *
* Description:                                                                *
*    Free memory allocated for field list, but not the data it points to.     *
*                                                                             *
* Return Value:                                                               *
*    none                                                                     *
*                                                                             *
* Arguments;                                                                  *
*                                                                             *
*    Input Arguments:                                                         *
*       List                                                                  *
*          FIELD_LIST, Reference                                              *
*             The field list we're deleting from memory.                      *
*    Input/Output Arguments:                                                  *
*       none                                                                  *
*    Output Arguments:                                                        *
*       none                                                                  *
*                                                                             *
* History:                                                                    *
*    Created    : 17-AUG-93 by J. Doggett,                                    *
*       for the Association of Universities for Research in Astronomy, Inc.   *
*          at the Space Telescope Science Institute,                          *
*       to facilitate the accessing of data from the CD-ROM set of the        *
*          Digitized Sky Survey.                                              *
*    Delivered  : 01-MAR-94 by J. Doggett,                                    *
*       GetImage Version 1.0                                                  *
******************************************************************************/
/*********************************
* Delete_Field_List declarations *
*********************************/
void       Delete_Field_List( List )
FIELD_LIST List;
{
/******************************************
* Delete_Field_List begin executable code *
******************************************/
   Delete_Linked_List( List );

   return;
}
/****************************************
* Delete_Field_List end executable code *
****************************************/

/******************************************************************************
* Module:                                                                     *
*    Delete_Field_List_Data                                                   *
*                                                                             *
* File:                                                                       *
*    fieldlst.c                                                               *
*                                                                             *
* Description:                                                                *
*    Free memory allocated for field list, but AND the data it points to.     *
*                                                                             *
* Return Value:                                                               *
*    none                                                                     *
*                                                                             *
* Arguments;                                                                  *
*                                                                             *
*    Input Arguments:                                                         *
*       List                                                                  *
*          FIELD_LIST, Reference                                              *
*             The field list we're deleting from memory.                      *
*    Input/Output Arguments:                                                  *
*       none                                                                  *
*    Output Arguments:                                                        *
*       none                                                                  *
*                                                                             *
* History:                                                                    *
*    Created    : 17-AUG-93 by J. Doggett,                                    *
*       for the Association of Universities for Research in Astronomy, Inc.   *
*          at the Space Telescope Science Institute,                          *
*       to facilitate the accessing of data from the CD-ROM set of the        *
*          Digitized Sky Survey.                                              *
*    Delivered  : 01-MAR-94 by J. Doggett,                                    *
*       GetImage Version 1.0                                                  *
******************************************************************************/
/**************************************
* Delete_Field_List_Data declarations *
**************************************/
void       Delete_Field_List_Data( List )
FIELD_LIST List;
{
/***********************************************
* Delete_Field_List_Data begin executable code *
***********************************************/
   Delete_Linked_List_Data( List, Delete_Field );

   return;
}
/*********************************************
* Delete_Field_List_Data end executable code *
*********************************************/

